==> nextcloud-25.0.8.tgz: nextcloud/apps/serverinfo/l10n/en_GB.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU info not available",
    "Load average: {cpu} (last minute)" : "Load average: {cpu} (last minute)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}",
    "RAM info not available" : "RAM info not available",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}",
    "SWAP info not available" : "SWAP info not available",
    "Not supported!" : "Not supported!",
    "Press ⌘-C to copy." : "Press ⌘-C to copy.",
    "Press Ctrl-C to copy." : "Press Ctrl-C to copy.",
    "System" : "System",
    "Monitoring" : "Monitoring",
    "Monitoring app with useful server information" : "Monitoring app with useful server information",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc.",
    "Operating System:" : "Operating System:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Unknown Processor",
    "Memory:" : "Memory:",
    "Server time:" : "Server time:",
    "Uptime:" : "Uptime:",
    "Temperature" : "Temperature",
    "Load" : "Load",
    "Memory" : "Memory",
    "Disk" : "Disk",
    "Mount:" : "Mount:",
    "Filesystem:" : "Filesystem:",
    "Size:" : "Size:",
    "Available:" : "Available:",
    "Used:" : "Used:",
    "You will get a notification once one of your disks is nearly full." : "You will get a notification once one of your disks is nearly full.",
    "Files:" : "Files:",
    "Storages:" : "Storages:",
    "Free Space:" : "Free Space:",
    "Network" : "Network",
    "Hostname:" : "Hostname:",
    "DNS:" : "DNS:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Speed:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Active users",
    "Total users:" : "Total users:",
    "24 hours:" : "24 hours:",
    "1 hour:" : "1 hour:",
    "5 mins:" : "5 mins:",
    "Shares" : "Shares",
    "Users:" : "Users:",
    "Groups:" : "Groups:",
    "Links:" : "Links:",
    "Emails:" : "Emails:",
    "Federated sent:" : "Federated sent:",
    "Federated received:" : "Federated received:",
    "Talk conversations:" : "Talk conversations:",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory limit:" : "Memory limit:",
    "Max execution time:" : "Max execution time:",
    "Upload max size:" : "Upload max size:",
    "OPcache Revalidate Frequency:" : "OPcache Revalidate Frequency:",
    "Extensions:" : "Extensions:",
    "Unable to list extensions" : "Unable to list extensions",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "External monitoring tool",
    "You can connect an external monitoring tool by using this end point:" : "You can connect an external monitoring tool by using this end point:",
    "Copy" : "Copy",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Appending \"?format=json\" at the end of the URL gives you the result in JSON.",
    "To use an access token, please generate one then set it using the following command:" : "To use an access token, please generate one then set it using the following command:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Then pass the token with the \"NC-Token\" header when querying the above URL."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.1p0.tgz: nextcloud/apps/serverinfo/l10n/en_GB.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU info not available",
    "Load average: {cpu} (last minute)" : "Load average: {cpu} (last minute)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}",
    "RAM info not available" : "RAM info not available",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}",
    "SWAP info not available" : "SWAP info not available",
    "Not supported!" : "Not supported!",
    "Press ⌘-C to copy." : "Press ⌘-C to copy.",
    "Press Ctrl-C to copy." : "Press Ctrl-C to copy.",
    "System" : "System",
    "Monitoring" : "Monitoring",
    "Monitoring app with useful server information" : "Monitoring app with useful server information",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc.",
    "Operating System:" : "Operating System:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Unknown Processor",
    "Memory:" : "Memory:",
    "Server time:" : "Server time:",
    "Uptime:" : "Uptime:",
    "Temperature" : "Temperature",
    "Load" : "Load",
    "Memory" : "Memory",
    "Disk" : "Disk",
    "Mount:" : "Mount:",
    "Filesystem:" : "Filesystem:",
    "Size:" : "Size:",
    "Available:" : "Available:",
    "Used:" : "Used:",
    "Files:" : "Files:",
    "Storages:" : "Storages:",
    "Free Space:" : "Free Space:",
    "Network" : "Network",
    "Hostname:" : "Hostname:",
    "DNS:" : "DNS:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Speed:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Active users",
    "Total users:" : "Total users:",
    "24 hours:" : "24 hours:",
    "1 hour:" : "1 hour:",
    "5 mins:" : "5 mins:",
    "Shares" : "Shares",
    "Users:" : "Users:",
    "Groups:" : "Groups:",
    "Links:" : "Links:",
    "Emails:" : "Emails:",
    "Federated sent:" : "Federated sent:",
    "Federated received:" : "Federated received:",
    "Talk conversations:" : "Talk conversations:",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory limit:" : "Memory limit:",
    "Max execution time:" : "Max execution time:",
    "Upload max size:" : "Upload max size:",
    "OPcache Revalidate Frequency:" : "OPcache Revalidate Frequency:",
    "Extensions:" : "Extensions:",
    "Unable to list extensions" : "Unable to list extensions",
    "Show phpinfo" : "Show phpinfo",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "External monitoring tool",
    "You can connect an external monitoring tool by using this end point:" : "You can connect an external monitoring tool by using this end point:",
    "Copy" : "Copy",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Appending \"?format=json\" at the end of the URL gives you the result in JSON.",
    "To use an access token, please generate one then set it using the following command:" : "To use an access token, please generate one then set it using the following command:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Then pass the token with the \"NC-Token\" header when querying the above URL.",
    "You will get a notification once one of your disks is nearly full." : "You will get a notification once one of your disks is nearly full."
},
"nplurals=2; plural=(n != 1);");
